# Info-UNASUS

Modelo para desenvolvimento de infográfico.

# Sumário

- [Estrutura dos arquivos](#estrutura-dos-arquivos)
- [O que é React?](#o-que-e-react)
- [O que são Hooks?](#o-que-sao-hooks)
- [Como utilizar o sistema de Rotas](#como-utilizar-sistema-de-rotas)
- [Como organizar uma página do infográfico](#como-organizar-uma-pagina-do-infografico)
  - [Estrutura do arquivo index.js](#estrutura-do-arquivo-index.js)
  - [Estrutura do arquivo styles.js](#estrutura-do-arquivo-styles.js)
- [Como estilizar no material UI](#como-estilizar-no-material-ui)
  - [Como utilizar makeStyles](#como-utilizar-makestyles)
  - [Como utilizar o styled-components no Material UI](#como-utilizar-o-styled-components-no-material-ui)
- [Como utilizar o tema](#como-utilizar-o-tema)
  - [Usando tema no makeStyles](#usando-tema-no-makestyles)
  - [Usando tema no Styled-components](#usando-tema-no-styled-components)
- [Como utilizar os componentes presentes no infográfico](#como-utilizar-os-componentes-presentes-no-infografico)
  - [Accordion](#accordion)
  - [Activities](#activities)
  - [AnimatedList](#animatedlist)
  - [Attention](#attention)
  - [ContourBox](#contourbox)
  - [Dialog](#dialog)
  - [ShadedBox](#shaded-box)
  - [Simple](#simple)
  - [Slide](#slide)
  - [Zoom](#zoom)
  - [Extensive](#extensive)
  - [TimeLine](#timeline)
  - [ButtonContent](#buttoncontent)
  - [Footer](#footer)
  - [PhotoPainel](#photopainel)
  - [Reference](#reference)
  - [Contraste](#contraste)
  - [NOVO SISTEMA DE QUESTÕES COM NOTAS](#notas)
- [Dicas](#dicas)
  - [Contraste](#dicas-contraste)
  - [IOS](#dicas-ios)
  - [Leitor de Tela](#dicas-leitor)

# Estrutura dos arquivos <a name="estrutura-dos-arquivos"></a>

```
src/
|
|-- components/
|     |-- core/
|-- pages/
      |-- p1/
          |-- index.js
          |-- styles.js
|-- store
|-- config.js
|-- index.js
|-- routes.js
|-- theme.js
|-- .gitignore
|-- package.json
|-- README.md
```

# O que é React? <a name="o-que-e-react"></a>

Sobre o funcionamento do React segue um conjunto de links explicando seu funcionamento.

[Introdução ao React](https://pt-br.reactjs.org/docs/getting-started.html)

[Pensando do jeito React](https://pt-br.reactjs.org/docs/thinking-in-react.html)

[Iniciando no React - Diego Fernandes](https://www.youtube.com/watch?v=7A4UQGrFU9Q)

# O que são Hooks? <a name="o-que-sao-hooks"></a>

Para o estudo sobre os hooks, segue links de estudos:

[Introdução aos Hooks - React](https://pt-br.reactjs.org/docs/hooks-intro.html)

[React Hooks na prática - Diego Fernandes](https://www.youtube.com/watch?v=6WB16wZS61c)

# Como utilizar o sistema de Rotas <a name="como-utilizar-sistema-de-rotas"></a>

O sistema de rotas é feito através do react-router-dom onde é utilizado o lazy e o Suspense do React para gerar o lazy loading. Para adicionar uma rota primeiro o componente precisa ser importado e e ser passado como parâmetro para a função lazy como uma arrow function. Em seguida no HTML da página é utilizado o Route para definir o caminho da url será utilizado e qual componente será exibido quando a rota for acessada.

```
import React, { Suspense, lazy} from 'react';
import {HashRouter, Switch, Route} from 'react-router-dom';

const p1 = lazy(() => import('./pages/p1'))
const p1_creditos = lazy(() => import('./pages/p1_creditos'))
const p2 = lazy(() => import('./pages/p2'))

export default () => (
    <HashRouter>
        <Suspense fallback={<div></div>}>
            <Switch>
                <Route exact path="/" component={p1} />
                <Route path="/creditos" component={p1_creditos} />
                <Route path="/p2" component={p2} />
            </Switch>
        </Suspense>
    </HashRouter>
);
```

# Como organizar uma página do infográfico <a name="como-organizar-uma-pagina-do-infografico"></a>

Cada página é formada por uma pasta na qual contém dois arquivos um onde é o index.js e o outro onde é o styles.js sendo utilizado para guardar a estilização da página.

## Estrutura do arquivo index.js <a name="estrutura-do-arquivo-index.js"></a>

```
import React from 'react'
import { Typography, Box } from '@material-ui/core'
import useStyles from './styles'
export default function () {
    const classes = useStyles()

    return (
        <>
            <Box overflow="auto" width="1" height="1">
                <Typography variant="h1" className={classes.text}>
                    H1
                </Typography>
            </Box>
        </>
    )
}
```

## Estrutura do arquivo styles.js <a name="estrutura-do-arquivo-styles.js"></a>

```
import { makeStyles } from '@material-ui/core/styles';

export default makeStyles(theme => ({
  text: {
    color: "#F0F0F0"
  },
  panels: {
    height: "65%",
    maxHeight: "200px"
  }
}));
```

# Como estilizar no material UI <a name="como-estilizar-no-material-ui"></a>

## Como utilizar makeStyles <a name="como-utilizar-makestyles"></a>

O material UI disponibiliza o Hook API para estilizar os componentes.

[MaterialUI-Estilos](https://material-ui.com/pt/styles/basics/#primeiros-passos)

## Como utilizar o styled-components no Material UI <a name="como-utilizar-o-styled-components-no-material-ui"></a>

Os componentes do material UI também podem ser customizado por meio do styled-components. E na documentação do Material UI sobre a interoperabilidade dos estilos ele menciona o uso do styled-components

[Interoperabilidade da Biblioteca de Estilo-Styled Components](https://material-ui.com/pt/guides/interoperability/#styled-components)

# Como utilizar o tema <a name="como-utilizar-o-tema"></a>

O uso de tema facilita a estilização, pois define cores padrões e tamanho de fonte que será utilizada por todo o projeto.

## Usando tema no makeStyles <a name="usando-tema-no-makestyles"></a>

```
const styles = makeStyles(theme => ({
  headerTitle: {
    backgroundColor: theme.palette.primary.main,
    color: "#FFF"
  }
}));
```

## Usando tema no Styled-components <a name="usando-tema-no-styled-components"></a>

```
import styled from 'styled-components'
import Grid from '@material-ui/core/Grid'

export const Container = styled(Grid)`
    width: 100%;
    height: 100vh !important;

    #center-container{
        height: 100%;

        background-color: ${props => props.theme.palette.background.main};
    }
`
```

# Como utilizar os componentes presentes no infográfico <a name="como-utilizar-os-componentes-presentes-no-infografico"></a>

## Accordion <a name="accordion"></a>

<img src='./src/assets/readme/accordion.png' alt='accordion'>

Importe o Accordion

```
import Accordion from "../../components/Accordion";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Accordion content={content} />
```

O 'content' é uma lista de objetos que deve conter a seguinte estrutura:

```
const content = [
    {
      painel: "1",
      title: "Exemplo 1",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est.",
    },
    {
      painel: "2",
      title: "Exemplo 2",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est.",
    },
    {
      painel: "3",
      title: "Exemplo 3",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est. ",
    },
  ];
```

## Activities <a name="activities"></a>

<img src='./src/assets/readme/activities.png' alt='activities'>

Importe o Activities

```
import Activities from '../../components/Activities'
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Activities
  key='NomedoInfo_Q1'
  respostas={respostas}
  alternativas={alternativas}
  objetivo='Reconhecer os sinais e sintomas que, associados a diarreia ou vômito, indicam necessidade atendimento com urgência e/ou encaminhamento imediato.'
  numQuestao={7}
  questao='A presença de sintomas de diarreia ou vômitos pode estar relacionada a outras condições de saúde que devem ser aferidas, a fim de avaliar necessidade de atendimento de urgência e/ou encaminhamento5. Entre os sinais e sintomas iniciais mais graves quando associados a diarreia e vômito, indicativos da necessidade de atendimento de urgência e/ou encaminhamento, está:'
/>
```

- key: chave da questao - irá diferenciá-la das outras questões. Aconselho seguir o modelo utilizado no exemplo;
- objetivo: texto referente ao Objetivo Educacional;
- numQuestao: número referente a questão;
- questao: enunciado da questão.

Respostas: são as respostas que aparecerá na mensagem de correção. É uma lista de objetos que deve conter a seguinte estrutura:

```
const respostas = [
    {
      alternativa: 'a',
      validacao: 'incorreta',
      resposta:
        'a) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'b',
      validacao: 'incorreta',
      resposta:
        'b) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'c',
      validacao: 'correta',
      resposta:
        'c) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'd',
      validacao: 'incorreta',
      resposta:
        'd) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    }
  ]
```

Alternativas: são as alternativas de escolha do aluno. É uma lista de objetos que deve conter a seguinte estrutura:

```
const alternativas = [
    { alternativa: 'a', texto: 'a) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'b', texto: 'b) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'c', texto: 'c) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'd', texto: 'd) Vivamus suscipit tortor eget felis porttitor volutpat.' }
  ]
```

## AnimatedList <a name="animatedlist"></a>

<img src='./src/assets/readme/animatedList.png' alt='animated list'>

Importe o AnimatedList

```
import AnimatedList from '../../components/AnimatedList';
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<AnimatedList
  list={list}
  paresColor='#fff'
  paresBackgroundColor='#00B5B1'
  imparesColor='#fff'
  imparesBackgroundColor='#00CFCA'
/>
```

- paresColor: cor do texto dos elementos pares;
- paresBackgroundColor: cor do background dos elementos pares;
- imparesColor: cor do texto dos elementos impares;
- imparesBackgroundColor: cor do background dos elementos impares;

O "list" é uma lista de strings que deve conter a seguinte estrutura:

```
const list = [
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.'
  ]
```

## Attention <a name="attention"></a>

<img src='./src/assets/readme/attention.png' alt='attention'>

Importe o Attention e, caso necessite, importe também a imagem do icone que ficará do lado do título:

```
import Attention from "../../components/Attention";
import important from "../../assets/icons/ATENCAO.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Attention image={important} title='IMPORTANTE'>
  Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.
</Attention>
```

- image: ícone que ficará ao lado do Título;
- title: Título do Attention;
- color: Cor do título;
- border: Cor da borda;
- O conteudo deverá ser colocado dentro das tags, enviado como children.

## ContourBox <a name="contourbox"></a>

<img src='./src/assets/readme/contourbox.png' alt='contour box'>

Importe o ContourBox e, caso necessite, importe também a imagem do icone que ficará ao lado do texto no conteúdo:

```
import ContourBox from "../../components/ContourBox";
import image from "../../assets/images/unnamed.jpg";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<ContourBox image={image}>
  Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.
</ContourBox>
```

- alt: coloca a legenda da imagem que é detectada no leitor de tela
- image: Imagem que acompanhará o conteúdo em texto;
- border: Cor da borda;
- height: Controla a altura do ContourBox - padrão: auto;
- O conteudo deverá ser colocado dentro das tags, enviado como children.

## Dialog <a name="dialog"></a>

<img src='./src/assets/readme/dialog1.png' alt='dialog button'>
<img src='./src/assets/readme/dialog2.png' alt='dialog modal'>

Importe o Dialog e, caso necessite, importe também a imagem do botão:

```
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Dialog
  content={content}
  title='Exemplo de Dialog'
  image={SaberMais}
/>
```

- content: conteúdo do Dialog;
- title: título do Dialog;
- image: imagem que será usada como butão, caso exista;
- clicked: determina se o botão ja foi clicado ou não(true ou false);
- help: se utilizado, o botão do Dialog será o icone "?";
- buttonText: se utilizado, o botão sera um texto com fundo;
- colorText: cor do texto do buttonText;
- colorBackground: define a cor do background do botão.
- colorBackgroundHover: define a cor do backgroundHover do botão.

## ShadedBox <a name="shaded-box"></a>

<img src='./src/assets/readme/shadedbox.png' alt='shaded box'>

Importe o ShadedBox e, caso necessite, importe também a imagem que acompanhará o conteúdo:

```
import ShadedBox from "../../components/ShadedBox";
import imageTest from "../../assets/images/garota.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<ShadedBox
  content={content}
  backgroundColor='#00B5B1'
  color='#fff'
  image={imageTest}
  right
  alt='legenda da imagem'
/>
```

- content: conteúdo do ShadedBox;
- image: imagem que acompanhará o conteúdo do ShadedBox;
- color: cor do texto do conteúdo - padrão: #000;
- backgroundColor: cor do background do conteúdo - padrão: #fff;
- alt: legenda da imagem que será lida no leitor de tela;
- right: com esta propriedade a imagem ficará a direita do conteúdo.

## Simple <a name="simple"></a>

<img src='./src/assets/readme/simple.png' alt='simple'>

Importe o Simple:

```
import Simple from "../../components/Simple";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Simple content={content} borderColor='#00B5B1' color='#00B5B1' />
```

- content: conteúdo do Simple;
- color: cor do texto do conteúdo;
- borderColor: cor da borda do conteúdo;

## Slide <a name="slide"></a>

<img src='./src/assets/readme/slide.png' alt='slide'>

Importe o Slide e as imagens que fará parte dele:

```
import Slide from "../../components/Slide";
import imagemEx from "../../assets/images/unnamed.jpg";
import imagemEx2 from "../../assets/images/unnamed2.png";
import imagemEx3 from "../../assets/images/unnamed3.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Slide content={material} />
```

O conteúdo do "content" deve ser um array de objetos com a seguinte estrutura:

```
const material = [
    {
      img: imagemEx,
      text: (
        <p>
          Como Usar: Para usar o Slide é passado uma propriedade Content com uma
          lista de objetos. Cada objeto pode conter um 'img', um 'alt' e um 'text'
        </p>
      ),
      alt: 'imagem exempo 1',
    },
    { img: imagemEx2, alt: 'imagem exempo 2' },
    {
      text: (
        <p>
          Texto 3 Vivamus magna justo, lacinia eget consectetur sed, convallis
          at tellus. Vivamus suscipit tortor eget felis porttitor volutpat. Cras
          ultricies ligula sed magna dictum porta. Quisque velit nisi, pretium
          ut lacinia in, elementum id enim. Mauris blandit aliquet elit, eget
          tincidunt nibh pulvinar a.
        </p>
      ),
    },
  ];
```

## Zoom <a name="zoom"></a>

<img src='./src/assets/readme/zoom1.png' alt='zoom miniatura'>
<img src='./src/assets/readme/zoom2.png' alt='zoom aberto'>

Importe o Zoom e a imagem:

```
import Zoom from "../../components/Zoom";
import garota from "../../assets/images/garota.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Zoom src={garota} alt="garota" />
```

## Extensive <a name="extensive"></a>

<img src='./src/assets/readme/extensive.png' alt='extensive'>

Importe o Extensive

```
import Extensive from "../../components/Extensive";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Extensive content={conteudoExtenso} />

```

O content deve conter um objeto com o titulo(title) do conteúdo, e o 'array' com os textos. Exemplo:

```
const conteudoExtenso = {
    title: 'Titulo do Conteúdo',
    array: ['Conteúdo 1', 'Conteúdo 2', 'Conteúdo 3', 'Conteúdo 4', 'Conteúdo 5']
  }

```

## TimeLine <a name="timeline"></a>

<img src='./src/assets/readme/timeline.png' alt='timeline'>

Importe o TimeLine

```
import TimeLine from "../../components/TimeLine";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<TimeLine content={contentTimeLine} />

```

O content deve conter um array de objetos que contém o ano e o texto. Exemplo:

```
const contentTimeLine = [{
    ano: '2010',
    texto: 'Conteudo de 2010'
  }, {
    ano: '2011',
    texto: 'Conteudo de 2011'
  }, {
    ano: '2012',
    texto: 'Conteudo de 2012'
  }, {
    ano: '2013',
    texto: 'Conteudo de 2013'
  }, {
    ano: '2014',
    texto: 'Conteudo de 2014'
  }, {
    ano: '2015',
    texto: 'Conteudo de 2015'
  }]

```

## ButtonContent <a name="buttoncontent"></a>

<img src='./src/assets/readme/buttonContent.png' alt='button content'>

Importe o ButtonContent

```
import ButtonContent from '../../components/ButtonContent';
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<ButtonContent content={content} />

```

O content deve conter um array de objetos seguindo este exemplo:

```
const content = [
    {
      button: 'A',
      texts: [
        {
          title: 'Altamira',
          text: (
            <p>
              Altamira é um município brasileiro localizado no estado do Pará...
            </p>
          ),
        },
        {
          title: 'Amazonas',
          text: (
            <p>
              Amazonas é uma das 27 unidades federativas do Brasil. Está situado...
            </p>
          ),
        },
      ],
    },
    {
      button: 'B',
      texts: [
        {
          title: 'Belém',
          text: (
            <p>
              Belém (inicialmente Santa Maria de Belém do Pará e frequentemente...
            </p>
          ),
        },
        {
          title: 'BTS',
          text: (
            <p>
              BTS, também conhecido como Bangtan Boys (hangul: 방탄소년단...
            </p>
          ),
        },
      ],
    },
  ];

```

## Footer <a name="footer"></a>

<img src='./src/assets/readme/footer1.png' alt='footer'>
<img src='./src/assets/readme/footer2.png' alt='footer com logos'>

Importe o Footer

```
import Footer from '../../components/Footer';
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Footer next='/p2' prev='/' />

```

- replay: página para que o botao deve retornar, geralmente é para uma página de menus;
- prev: página anterior;
- next: próxima página;
- logos: caso queira exibir as logomarcas no footer - geralmente é usado na capa;
- color: define uma cor para a barra do footer. Sem essa propriedade, o padrão segue a paleta de cores.

## PhotoPainel <a name="photopainel"></a>

<img src='./src/assets/readme/photopainel.png' alt='photopainel'>

Importe o PhotoPainel e as imagens que aparecerão nos cards

```
import PhotoPainel from '../../components/PhotoPainel';
import image from "../../assets/images/unnamed.jpg";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<PhotoPainel content={arrayPhotoPainel} />

```

O content deve conter um array de objetos seguindo este exemplo:

```
 const arrayPhotoPainel = [
    { image: imagem, alt: 'imagem1', title: 'titulo 1', text: 'conteúdo 1' },
    { image: imagem, alt: 'imagem2', title: 'titulo 2', text: 'conteúdo 2' },
    { image: imagem, alt: 'imagem3', title: 'titulo 3', text: 'conteúdo 3' },
    { image: imagem, alt: 'imagem4', title: 'titulo 4', text: 'conteúdo 4' },
    { image: imagem, alt: 'imagem5', title: 'titulo 5', text: 'conteúdo 5' },
    { image: imagem, alt: 'imagem6', title: 'titulo 6', text: 'conteúdo 6' },
    { image: imagem, alt: 'imagem7', title: 'titulo 7', text: 'conteúdo 7' },
  ];

```

## Reference <a name="reference"></a>

<img src='./src/assets/readme/referencia1.png' alt='referencia1'>
<img src='./src/assets/readme/referencia2.png' alt='referencia2'>

Importe o Reference e o useRef do react

```
import React, { useRef } from 'react';
import Reference from '../../components/Reference';
```

Dentro da função da pagina, coloque o seguinte codigo responsavel por abrir o drawer na referência exata:

```
const headerref = useRef(Header);
const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };
```

No header adicione a propriedade ref={headerref} que contem o useref antes criado, exemplo:

```
<Header ref={headerref} />
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo alterando os numeros de acordo com a referência desejada:

```
<Reference num='1' onClick={() => openRef(1)} />

```

## Contraste <a name="contraste"></a>

Para utilizar o contraste, é preferível que esteja usando o styled-component.

Na pasta './src/theme/Palette' existem duas paletas de cores: light e dark, ambas tem os mesmos nomes para suas cores.
Segue o exemplo:

```
black: '#000',
white: '#fff',
grey: '#272727',
primary: '#00b5b1',
secondary: '#317C7C',
titles: '#169e90',
light: '#E0f6f1',
hover: '#439999',
```

obs: você pode criar novas cores, dependendo da sua necessidade, mas lembre-se de criar nos dois arquivos;

Para selecionar uma cor, você deve primeiramente pensar em qual tom ela estará no modo dark, são apenas 3 tons: white, black e grey.

Exemplo: se você tem um texto e quer ele na cor 'primary' e que no modo dark ele fique preto, você colocará no styled a seguinte estrutura:

p{
color: ${ props => props.theme.palette.black.primary}
}

Analisando a estrutura acima percebemos que após a palavra 'palette', selecionamos a cor no modo dark e depois a cor no modo light:

```
props.theme.palette.'COR EM MODO DARK'.'COR EM MODO LIGHT'
```

assim, as cores serão alteradas automaticamente ao alternar o contraste.

## NOVO SISTEMA DE QUESTÕES COM NOTAS <a name="notas"></a>

Para iniciar, no index do projeto deve ser especificado o total de questões, no exemplo abaixo são duas:

```
ReactDOM.render(
  <Provider store={store}>
    <QuestionsContextProvider totalQuestions={2}>
      <App />
    </QuestionsContextProvider>
  </Provider>,
  document.getElementById('root')
);
```

O proximo passo é preencher as questoes e suas respostas no componente 'QuestionsSystem/questions.js' seguindo a seguinte estrutura:

```
const questions = [
{
  description: 'Pergunta',
  options: [
    'a) Comunicação',
    'b) Adaptações razoáveis',
    'c) Acessibilidade',
    'd) Tecnologia Assistiva',
  ],
  feedbacks: [
    'Feedback A',
    'Feedback B',
    'Feedback C',
    'Feedback D',
  ],
correct: '0',
},
];

export default questions;
```

description: Pergunta da questão;
options: array com as alternativas;
feedbacks: array com o feedback das alternativas;
correct: valor equivalente a alternativa, exemplo: a-0, b-1, c-2, d-3.

Em 'components/QuestionsSystem/contexts/QuestionsContext.js' altere a const '\_gereralApiKey' para um algo que tenha relação com o infográfico. Exemplo:

```
const _gereralApiKey = 'info_somativa_mariana_deficiencia';
```

Em 'components/QuestionsSystem/contexts/API.js' altere em sendGrade o endpoint relativo ao seu infográfico, exemplo: '/grades/acessibilidade_unidade_1'.

Na página anterior ao início das questoes, temos que fazer a chamada para as questões(existe o modelo pronto na p16).

Primeiro importe o questionsContext:

```
import { QuestionsContext } from '../../components/QuestionsSystem/contexts/QuestionsContext';
```

Dentro da função da página, atribua o QuestionsContext a uma variavel de contexto react:

```
const questionsContext = React.useContext(QuestionsContext);
```

Crie as funções de iniciar tentativa e ver resultados:

```
function iniciarTentativa() {
    questionsContext.initQuestions();
    // colocar aqui a pagina da primeira questão
    window.location.href = '#/q1';
  }

  function verResultados() {
    questionsContext.goToFeedbacks();
    // colocar aqui a pagina da primeira questão
    window.location.href = '#/q1';
  }
```

E crie botões para cada função. Note abaixo que o botão 'ver resultados' só aparece quando já foi realizada uma tentativa.

```
<button
  onClick={iniciarTentativa}
  disabled={questionsContext.attemptsCount === 3}
  className='buttonQuestions noRead'
  style={{
    opacity: questionsContext.attemptsCount === 3 ? 0.6 : 1,
  }}
>
  Iniciar Teste
</button>
<p className='d-none'>Botão Iniciar Teste.</p>
{questionsContext.attemptsCount > 0 && (
  <>
    <button
      className='buttonQuestions'
      onClick={verResultados}
      style={{ marginLeft: 16 }}
      className='buttonQuestions noRead'
    >
      Ver Resultados
    </button>
    <p className='d-none'>Botão Ver Resultados.</p>
  </>
)}
```

Para ciar a página de questões, 'q1' por exemplo, apenas faça a estrutura abaixo. Isso já redenrizará a página de questões existente.
Lembre-se de numerar a questão no 'questionId'.

```
import React from 'react';
import QuestionPage from '../components/QuestionsSystem/components/QuestionPage';

export default function () {
  return <QuestionPage questionId={1} />;
}
```

Na pagina de feedback(existe um modelo pronto, pagina feedback), importe o 'QuestionsContext' e as 'questions'

```
import { QuestionsContext } from '../../components/QuestionsSystem/contexts/QuestionsContext';
import questions from '../../components/QuestionsSystem/questions';
```

Dentro da função da página, atribua o QuestionsContext a uma variavel de contexto react:

```
const questionsContext = React.useContext(QuestionsContext);
```

Faça a função que contara os acertos e verificará a nota.

```
const acertos = useMemo(() => {
    if (questionsContext.lastTest) {
      const correctsCount = questionsContext.lastTest.answers.filter(
        (answer, index) => {
          const correct = questions[index].correct;
          return correct === answer;
        }
      ).length;

      return correctsCount;
    } else {
      return 0;
    }
  }, [questionsContext.lastTest]);
```

e a função de rtornar a pagina de chamada das questões:

```
function retornar() {
    // colocar abaixo a pagina de chamada para as questoes
    window.location.href = '#/p16';
  }
```

Para exibir acertos notas e tentativas, segue o exemplo:

```
<Typography variant='body1' className=''>
  Acertos:{' '}
  <span>
    {acertos} de {questions.length}
  </span>
  <br />
  <br />
  Nota:{' '}
  <span>
    {questionsContext.lastTest &&
      questionsContext.lastTest.grade.toFixed(2)}
  </span>
  <br />
  <br />
  Você ainda tem <span>
    {3 - questionsContext.attemptsCount}
  </span>{' '}
  tentativa(s)
</Typography>
```

E faça um botão para chamar a função de retornar, exemplo:

```
<button onClick={retornar}>
  <Typography variant='body1' className=''>
    Retornar
  </Typography>
</button>
```

# Dicas <a name="dicas"></a>

## Contraste <a name="dicas-contraste"></a>

Caso a estrutura convencional criada para o contraste não seja suficiente para algo específico no css,
voce pode importar a variavel do contraste.
Exemplo: Supondo que você quer que uma borda apareceça quando o contraste é ativado, voce primeiramente importa o redux para o seu index.js

```
import { useSelector } from 'react-redux';
```

Dentro da função do componente da pagina você recupera a variavel do contraste:

```
const contrasteValue = useSelector((state) => state.contraste);
```

Passe o valor para o styled component por meio do componente styled, exemplo:

```
<StyledContainer contraste={contrasteValue}>
```

No styled voce pode fazer um ternário:

```
border: ${props => props.contrasteValue ? 'solid 1px #000' : 'none' }
```

Assim você poderá fazer qualquer coisa para o contraste independente do modo normal, ou o contrário.

## IOS <a name="dicas-ios"></a>

No IOS alguns detalhes são bem importantes:

### IMG

É aconselhável usar uma div para controlar um img

```
<div className='image'>
  <img />
</div>
```

No css insira essas propriedades em img para q a div seja o responsável pelo controle dela.

```
img{
  max-width: 100%;
  box-sizing: border-box;
}
```

### Container

No IOS MOBILE o principal container da pagina, é preferível que seja display block, dessa forma ja existe um padrao nas paginas, que você nao deve alterar a nao ser que seja necessario:

```
display: block;
@media (min-width: 900px) {
  display: flex;
  flex-direction: column;
  overflow: hidden;
}
```

### Display

É sempre bom testar no IOS, pois é comum quebrar componentes filho que sãoo display flex dentro de componentes pais que também são display flex.

Caso dê problemas, teste utilizar display block no componente filho ou no componente pai.

## Leitor de Tela <a name="dicas-leitor"></a>

### Evitar leitura

Caso exista algum texto ou imagem que voce nãoo quer que o leitor de tela leia, colque 'noRead' no className:

```
<p className='noRead'>Lorem Ipsum is simply dummy text of the printing and typesetting industry.</p>
```

### Componente somente pra leitura

Caso exista alguma dificuldade de ordem de leitura de conteúdo ou outro problema, você pode colocar 'noRead' em todo o conteúdo e criar um componente específico somente para leitura, assim o leitor detectará e lerá o conteúdo mas nao será exibido visualmente em tela. Exemplo:

O leitor de tela ao ler o codigo abaixo seguirá a ordem de localização do texto, o que neste caso nao é interessante, afinal ele lerá primeiro todos os anos para depois ler os conteúdos respectivos.

```
<div>
  <p>2001</p>
  <p>2002</p>
  <p>2003</p>
  <p>conteudo 2001</p>
  <p>conteudo 2002</p>
  <p>conteudo 2003</p>
</div>
```

Para evitar esse problema, evite que ele leia esses componentes:

```
<div>
  <p className='noRead'>2001</p>
  <p className='noRead'>2002</p>
  <p className='noRead'>2003</p>
  <p className='noRead'>conteudo 2001</p>
  <p className='noRead'>conteudo 2002</p>
  <p className='noRead'>conteudo 2003</p>
</div>
```

Agora crie um componente estruturado, porem nao visivel para que seja somente identificado pelo leitor:

```
<div>
  <p className='noRead'>2001</p>
  <p className='noRead'>2002</p>
  <p className='noRead'>2003</p>
  <p className='noRead'>conteudo 2001</p>
  <p className='noRead'>conteudo 2002</p>
  <p className='noRead'>conteudo 2003</p>
</div>

<p>2001. conteúdo 2001. 2002. conteúdo 2002. 2003. conteúdo 2003. </p>
```

E para que esse conteudo nao seja exibido em tela:

```
<p className='leitor'>2001. conteúdo 2001. 2002. conteúdo 2002. 2003. conteúdo 2003. </p>
```

no css:

```
leitor{
  display: none
}
```
