import React, { useState, useEffect } from 'react';
import { Typography, Box, Button } from '@material-ui/core';
import API from '../../core/Lti/api';
import { useSelector } from 'react-redux';
import themeLight from '../../theme/Palette/Light/palette.js';
import themeDark from '../../theme/Palette/Dark/palette.js';

import Dialog from '../Dialog';

import { ContentActivities, Correta, Incorreta } from './styles';

export default function (props) {
  const contrasteValue = useSelector((state) => state.contraste);
  // const headerref = useRef(Header);

  const key = props.key;

  const theme = contrasteValue ? themeDark : themeLight;

  const [reply, setReply] = useState('');
  const [textoModal, setTextoModal] = useState([]);

  const [status, setStatus] = useState('');

  const sendAnswers = async (answers) => {
    await API.setData(key, { resposta: answers });
    props.respostas.map((item) => {
      if (item.alternativa === answers) {
        if (item.validacao === 'correta') {
          setStatus('Correta!');
          setTextoModal(
            <>
              <Correta key=''>
                <Typography variant='body1' className='correta'>
                  {item.resposta}
                </Typography>
              </Correta>
            </>
          );
        } else {
          setStatus('Incorreta!');
          setTextoModal(
            <>
              <Incorreta>
                <Typography variant='body1' className='incorreta'>
                  {item.resposta}
                </Typography>
              </Incorreta>
            </>
          );
        }
      }
    });
  };

  useEffect(() => {
    const init = async () => {
      const data = await API.getData(key);
      if (data) {
        setReply(data.resposta);
      }
      return false;
    };
    init();
  }, [key]);

  return (
    <ContentActivities contraste={contrasteValue}>
      <Box className='title'>
        <Typography variant='h5'>Atividades</Typography>
      </Box>
      <Box className='contentActivities'>
        <Box className='text'>
          <Typography variant='body1' className='indented'>
            <strong>Objetivo Educacional</strong>: {props.objetivo}
            {/* <p>
                Exemplo de referência<Reference num='1' onClick={() => openRef(1)}/>.
                </p> */}
          </Typography>
          <Typography variant='body1' className='indented'>
            <strong>Questão {props.numQuestao}</strong>: {props.questao}
          </Typography>
        </Box>
        <Box className='alternativas'>
          {props.alternativas.map((item, index) => {
            return (
              <Button
                key={index}
                variant='body1'
                className={
                  reply === item.alternativa
                    ? 'alternativa alternativaEscolhida'
                    : 'alternativa alternativaNaoEscolhida'
                }
                onClick={() => [setReply(item.alternativa)]}
              >
                {item.texto}
              </Button>
            );
          })}
        </Box>
        <Box className='boxDialog' onClick={() => [sendAnswers(reply)]}>
          <Dialog
            buttonText='enviar'
            classe='enviar'
            colorText={contrasteValue ? '#000' : '#fff'}
            colorBackground={theme.palette.white.primary}
            colorBackgroundHover={theme.palette.white.hover}
            content={textoModal}
            title={status}
          />
        </Box>
      </Box>
    </ContentActivities>
  );
}
