import React, { useEffect, useState } from 'react';
import {
  Box,
  Typography,
  Dialog,
  DialogContent,
  DialogContentText,
} from '@material-ui/core';
import Slide from '@material-ui/core/Slide';
import { makeStyles } from '@material-ui/core/styles';
import { useSelector } from 'react-redux';
// import RoundButton from "../RoundButton";

import { DialogStyles, DialogButton, CloseButton, ButtonText } from './styles';

import button_close from '../../assets/buttons/btn_fechar.png';
import button_close_contraste from '../../assets/buttons/btn_fechar-contraste.png';
import themeLight from '../../theme/Palette/Light/palette.js';
import themeDark from '../../theme/Palette/Dark/palette.js';
import themeDefault from '../../theme';
const Transition = React.forwardRef(function Transition(props, ref) {
  return <Slide direction='up' ref={ref} {...props} />;
});

const useStyles = makeStyles({
  Dialog: {},
  DialogTitle: {
    // background: (contraste) => theme.palette.black.white,
    background: (theme) => theme.palette.black.white,
    color: (theme) => theme.palette.white.components,
    display: 'flex',
    padding: themeDefault.spacing(2),
    '@media(min-width: 900px)': {
      padding: themeDefault.spacing(3),
    },
  },
  DialogTitleContent: {
    flexGrow: '1',
    display: 'flex',
    alignItems: 'center',
    color: (theme) => theme.palette.white.primary,
    h6: {
      lineHeight: 1.1,
    },
  },
  DialogContent: {
    background: (theme) => theme.palette.black.white,
    padding: themeDefault.spacing(2),
    maxHeight: '60vh',
    overflow: 'auto',
    '@media(min-width: 900px)': {
      padding: themeDefault.spacing(3),
    },
  },
  DialogContentText: {
    color: (theme) => theme.palette.white.grey,
  },
  Divider: {
    background: (theme) => theme.palette.white.components,
    height: '2px',
  },
});

export default function (props) {
  const contraste = useSelector((state) => state.contraste);
  const theme = contraste ? themeDark : themeLight;
  const [open, setOpen] = React.useState(false);
  const classes = useStyles(theme);
  const [alt, setAlt] = useState('');
  const {
    content,
    title,
    image,
    clicked,
    buttonText,
    colorText,
    colorBackground,
    colorBackgroundHover,
  } = props;

  const handleClickOpen = () => {
    setOpen(true);
  };

  useEffect(() => {
    let conteudoAlt = title;
    // if (content.props) {
    //   content.props.children.map((item) => {
    //     conteudoAlt = `${conteudoAlt}. ${item.props.children}`;
    //   });
    // }
    setAlt(conteudoAlt);
  });

  const handleClose = () => {
    setOpen(false);
  };

  return (
    <DialogStyles>
      {buttonText ? (
        <ButtonText
          variant='body1'
          className='indented'
          onClick={handleClickOpen}
          clicked={clicked}
          colorText={colorText}
          colorBackground={colorBackground}
          colorBackgroundHover={colorBackgroundHover}
        >
          <Typography variant='body1'>{buttonText}</Typography>
        </ButtonText>
      ) : (
        <DialogButton
          onClick={handleClickOpen}
          clicked={clicked}
          colorBackground={colorBackground}
          colorBackgroundHover={colorBackgroundHover}
        >
          <img src={image} alt={`botão ${alt}`} />
        </DialogButton>
      )}
      <Dialog
        open={open}
        TransitionComponent={Transition}
        keepMounted
        onClose={handleClose}
        aria-labelledby='alert-dialog-slide-title'
        aria-describedby='alert-dialog-slide-description'
        maxWidth='md'
        className={classes.Dialog}
      >
        <Box id='alert-dialog-slide-title' className={classes.DialogTitle}>
          <Box className={classes.DialogTitleContent}>
            <Typography variant='h6'>{title}</Typography>
          </Box>
          <CloseButton onClick={handleClose}>
            {contraste ? (
              <img src={button_close_contraste} alt='Fechar' />
            ) : (
              <img src={button_close} alt='Fechar' />
            )}
          </CloseButton>
        </Box>
        <Box className={classes.Divider} />
        <DialogContent className={classes.DialogContent}>
          <DialogContentText
            id='alert-dialog-slide-description'
            className={classes.DialogContentText}
          >
            <p>{content}</p>
          </DialogContentText>
        </DialogContent>
      </Dialog>
    </DialogStyles>
  );
}
