import React from 'react';
import IconButton from '@material-ui/core/IconButton';
import ReadIcon from '@material-ui/icons/RecordVoiceOver';
import StopIcon from '@material-ui/icons/Stop';
import { tooltips } from '../../../theme/commonstyles';
import Artyom from 'artyom.js';
import styled from 'styled-components';

import $ from 'jquery';

const StyledDiv = styled.div`
  margin-left: 0%;
  display: flex;
  > button {
    ${tooltips}
  }
  .speed {
    color: ${(props) => props.theme.palette.white.white};
    font-size: 0.7vw;
    @media (max-width: 900px) {
      font-size: 1.7vh;
    }
    font-weight: bold;
    display: flex;
    justify-content: center;
    align-items: center;
  }
  .menuButton {
    margin-left: 1vh;
    width: 35px;
    height: 35px;
    @media (min-width: 900px) {
      width: 2.8rem;
      height: 2.8rem;
    }
    @media (max-height: 800px) and (min-width: 900px) {
      width: 2rem;
      height: 2rem;
      position: relative;
      top: -17px;
    }
    box-shadow: 2px 2px 5px 0px rgba(0, 0, 0, 0.3),
      0 1px 2px rgba(0, 0, 0, 0.24);
    transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
    &:hover {
      background-color: ${(props) =>
        props.color ? props.color : props.theme.palette.black.componentsHover};
      color: ${(props) => props.theme.palette.white.white};
      box-shadow: 14px 14px 28px rgba(0, 0, 0, 0.25),
        0 8px 8px rgba(0, 0, 0, 0.22);

      svg {
        transform: scale(1.05);
      }
    }
  }
  .MuiIconButton-root {
    width: 35px;
    height: 35px;
    cursor: pointer;
    background-color: ${(props) => props.theme.palette.black.buttons};
    padding: 1.2vh;
    @media (min-width: 150vh) {
      padding: 0.9vh;
    }
    border: ${(props) => (props.contrasteValue ? '2px solid white' : 'none')};
  }
  .MuiIconButton-root:hover {
    background-color: ${(props) => props.theme.palette.black.buttonsHover};
  }
  .MuiSvgIcon-root {
    width: 15px;
    height: 15px;
    color: white;
    font-size: calc(2.6vh);
    @media (min-width: 150vh) {
      font-size: calc(3vh);
    }
    transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
    :hover {
      transform: scale(1.1);
    }
  }

  .stop_icon {
    display: none;
  }
  .leitor {
    display: none;
  }
`;

// Page
class ReadDrawer extends React.Component {
  constructor(props) {
    super(props);
    const artyom = new Artyom();
    this.state = {
      artyom: artyom,
      reading: false,
      knot: [],
      contraste: props.contrasteValue,
      speed: 1,
    };

    // this.state.artyom.fatality() // use this to stop any of // comentando isso funcionou no firefox

    setTimeout(() => {
      this.state.artyom
        .initialize({
          lang: 'pt-BR', // A lot of languages are supported. Read the docs !
          continuous: true, // recognize 1 command and stop listening !
          // listen: true, // Start recognizing
          debug: false, // Show everything in the console
          speed: 1, // talk normally
        })
        .then(function () {
          console.log('ready...');
        });
    }, 1);

    $(document).on('updatePage', () => {
      $(document).ready(() => {
        this.restart();
      });
    });
  }

  componentDidMount() {
    $(document).ready(() => {
      $('.read_icon').click(() => {
        this.readDOM();
        this.setState({ reading: true });
        $(document).trigger('log', [{ type: 'read_book' }]);
      });

      $('.stop_icon').click(() => {
        this.restart();
        this.setState({ reading: false });
      });
      this.restart();
    });
  }

  restart() {
    this.stopRead();
    this.lenghtPage();
  }

  getElementText(text, el) {
    // Text node (3) or CDATA node (4) - return its text
    if ($(el).hasClass('noRead')) {
      // if (el.getAttribute('alt'))
      //   text.push({ text: el.getAttribute('alt'), read: false });
    } else if (el.nodeType == 3 || el.nodeType == 4) {
      text.push({
        text: el.nodeValue,
        read: false,
      });
      // If node is an element (1) and an img, input[type=image], or area element, return its alt text
    } else if (
      el.nodeType === 1 &&
      (el.tagName.toLowerCase() === 'img' ||
        el.tagName.toLowerCase() === 'area' ||
        (el.tagName.toLowerCase() === 'input' &&
          el.getAttribute('type') &&
          el.getAttribute('type').toLowerCase() === 'image'))
    ) {
      if (el.getAttribute('alt'))
        text.push({ text: el.getAttribute('alt'), read: false });
      // Traverse children unless this is a script or style element
    } else if (el.nodeType === 1 && !el.tagName.match(/^(script|style)$/i)) {
      const children = el.childNodes;
      for (let i = 0, l = children.length; i < l; i++) {
        this.getElementText(text, children[i]);
      }
    }
  }

  lenghtPage() {
    $(document).ready(() => {
      const read = [];
      this.getElementText(
        read,
        document.getElementsByClassName('contentDrawer')[0]
      );
      this.setState({ knot: read });
      var lenght = read.length;
      localStorage.setItem('itens', lenght);
      localStorage.setItem('itensTotal', lenght);
    });
  }

  readTheSentece(element, index) {
    if (!element.read) {
      this.state.artyom.say(element.text, {
        onEnd: () => {
          const aux2 = this.state.knot;
          element.read = true;
          aux2[index] = element;
          this.setState({ knot: aux2 });
          var aux = localStorage.getItem('itens');
          var y = localStorage.getItem('itensTotal');
          var x = aux - 1;
          localStorage.setItem('itens', x);
          if (x === 0) {
            this.stopRead();
            localStorage.setItem('itens', y);
            this.state.knot.forEach((element) => {
              element.read = false;
            });
          }
        },
      });
    }
  }

  stopRead() {
    this.state.artyom.shutUp();
    $('.stop_icon').hide();
    $('.read_icon').show();
    this.setState({ reading: false });
  }

  readDOM() {
    $('.read_icon').hide();
    $('.stop_icon').show();
    this.state.knot.forEach((element, index) => {
      if (!element.read) {
        this.readTheSentece(element, index);
      }
    });
  }

  iniciar(vel) {
    this.state.artyom
      .initialize({
        lang: 'pt-BR', // A lot of languages are supported. Read the docs !
        continuous: true, // recognize 1 command and stop listening !
        // listen: true, // Start recognizing
        debug: false, // Show everything in the console
        speed: vel, // talk normally
      })
      .then(function () {
        console.log('ready...');
      });
  }

  alterarVelocidade() {
    if (this.state.speed === 1) {
      this.setState({ speed: 1.25 });
      this.iniciar(1.25);
    } else if (this.state.speed === 1.25) {
      this.setState({ speed: 1.5 });
      this.iniciar(1.5);
    } else if (this.state.speed === 1.5) {
      this.setState({ speed: 1.75 });
      this.iniciar(1.75);
    } else if (this.state.speed === 1.75) {
      this.setState({ speed: 2 });
      this.iniciar(2);
    } else if (this.state.speed === 2) {
      this.setState({ speed: 1 });
      this.iniciar(1);
    }
    this.restart();
    this.readDOM();
  }

  render() {
    return (
      <StyledDiv contrasteValue={this.props.contrasteValue} tooltip>
        <p className='leitor'>Botão “Áudio”</p>
        <IconButton
          edge='start'
          className='menuButton ReadDrawer read_icon'
          aria-label='menu'
        >
          <ReadIcon />
        </IconButton>
        <IconButton
          edge='start'
          className='menuButton ReadDrawer stop_icon'
          aria-label='menu'
        >
          <StopIcon />
        </IconButton>
        <IconButton
          className='menuButton ReadInfo speed noRead'
          aria-label='menu'
          onClick={() => this.alterarVelocidade()}
        >
          {`x${this.state.speed}`}
        </IconButton>
        <p className='leitor'>Botão Velocidade do Áudio</p>
      </StyledDiv>
    );
  }
}
export default ReadDrawer;
