import React, { useEffect } from 'react';
import RoundButton from '../RoundButton';
import { Toolbar, useMediaQuery, Typography } from '@material-ui/core';
import { Footer } from './styles';
import marcas from '../../assets/images/logos.png';
import { useSelector } from 'react-redux';

export default function (props) {
  const { replay, prev, next, logos, color } = props;
  const web = useMediaQuery('(min-width: 900px)');

  const contrasteValue = useSelector((state) => state.contraste);

  const pressPrev = document.querySelector('.pressPrev a');
  const pressNext = document.querySelector('.pressNext a');
  const pressReplay = document.querySelector('.pressReplay a');

  function handleKeyboardF(event) {
    const teste = window.location;
    if (teste.hash !== '#/') {
      if (event.key === 'ArrowLeft') {
        if (prev) {
          if (pressPrev) {
            pressPrev.click();
          }
        } else {
          return true;
        }
        window.removeEventListener('keydown', handleKeyboardF);
      } else if (event.key === 'ArrowRight') {
        if (next) {
          if (pressNext) {
            pressNext.click();
          }
        } else {
          return true;
        }
        window.removeEventListener('keydown', handleKeyboardF);
      } else if (event.key === 'ArrowDown') {
        if (replay) {
          if (pressReplay) {
            pressReplay.click();
          }
        } else {
          return true;
        }
        window.removeEventListener('keydown', handleKeyboardF);
      } else {
        return true;
      }
    }
  }

  window.addEventListener('keydown', handleKeyboardF);

  return (
    <>
      {logos ? (
        <Footer contraste={contrasteValue} color={color} logos>
          <img src={marcas} alt='Instituições responsáveis pelo curso' />
        </Footer>
      ) : (
        <Footer contraste={contrasteValue} color={color}>
          <Toolbar>
            {replay ? (
              <div className='pressReplay'>
                <RoundButton tooltip='Retornar' top type='replay' to={replay} />
                <Typography className='read'>Botão “Retornar”</Typography>
              </div>
            ) : (
              <RoundButton disabled />
            )}
            {web ? (
              <>
                <div className='middlebutton'>
                  {prev ? (
                    <div className='pressPrev'>
                      <RoundButton
                        tooltip='Página anterior'
                        top
                        type='previous'
                        to={prev}
                      />
                      <Typography className='read'>
                        Botão “Página Anterior”
                      </Typography>
                    </div>
                  ) : (
                    <>
                      <RoundButton type='previous' opacity />
                    </>
                  )}
                  {next ? (
                    <div className='pressNext'>
                      <RoundButton
                        tooltip='Próxima página'
                        top
                        type='next'
                        to={next}
                        margin
                      />
                      <Typography className='read'>
                        Botão “Próxima Página”
                      </Typography>
                    </div>
                  ) : (
                    <>
                      <RoundButton type='next' opacity margin />
                    </>
                  )}
                </div>
                <div className='placeholder'>
                  <RoundButton disabled />
                </div>
              </>
            ) : (
              <>
                <div className='endbutton'>
                  {prev ? (
                    <div className='pressPrev'>
                      <RoundButton type='previous' to={prev} />
                      <Typography className='read'>
                        Botão “Página Anterior”
                      </Typography>
                    </div>
                  ) : (
                    <RoundButton type='previous' opacity />
                  )}
                  {next ? (
                    <div className='pressNext'>
                      <RoundButton type='next' to={next} margin />
                      <Typography className='read'>
                        Botão “Próxima Página”
                      </Typography>
                    </div>
                  ) : (
                    <RoundButton type='next' opacity margin />
                  )}
                </div>
              </>
            )}
          </Toolbar>
        </Footer>
      )}
    </>
  );
}
