import React, { useRef, useImperativeHandle, forwardRef } from "react";

import Drawer from "../Drawer";

import { Toolbar, Typography } from "@material-ui/core";
import { StyledHeader } from "./styles";

import RoundButton from "../RoundButton";
import Dialog from "../Dialog";
import ReadInfo from "./ReadInfo/ReadInfo";
import Tutorial from "../Tutorial";
import Contraste from "../Contraste";
import { useSelector } from "react-redux";

const Header = (props, ref) => {
  const { help, download, nohome, cover, helpTitle, helpContent, acess } =
    props;
  const drawerref = useRef(Drawer);
  const contrasteValue = useSelector((state) => state.contraste);

  const openDrawer = async (key) => {
    if (!drawerref.current) {
      return;
    }

    await drawerref.current.openDrawer(key);
    drawerref.current.scrollList();
  };

  useImperativeHandle(ref, () => ({
    openRef: (key) => {
      openDrawer(key);
    },
  }));

  return (
    <StyledHeader cover={cover} contraste={contrasteValue}>
      <Toolbar className='padding'>
        {acess && <Tutorial />}
        <Drawer acess={acess} ref={drawerref} />
        <Typography className='read'>Botão “Menu”</Typography>
        {!nohome && (
          <>
            <Typography className='read'>Botão “Página Inicial”</Typography>
            <RoundButton tooltip='Início' to='/' type='home' margin={true} />
          </>
        )}
        {acess && <ReadInfo contrasteValue={contrasteValue} />}
        <div className='endbutton'>
          {acess && (
            <>
              <Typography className='read'>
                Botão “Ajuste de Contraste”
              </Typography>
              <Contraste />
            </>
          )}
          {help ? (
            <>
              <Typography className='read'>Botão “Ajuda”</Typography>
              <Dialog help title={helpTitle} content={helpContent} />
              {console.log(helpContent)}
            </>
          ) : (
            <></>
          )}
          {download ? (
            <>
              <Typography className='read'>Botão “Download”</Typography>
              <RoundButton tooltip='Versão pdf' type='download' margin />
            </>
          ) : (
            <></>
          )}
        </div>
      </Toolbar>
    </StyledHeader>
  );
};

export default forwardRef(Header);
