import React, { useContext, useEffect, useRef, useState } from 'react';
import { Typography, Box } from '@material-ui/core';

import { useSelector } from 'react-redux';
import Header from '../../../Header';
import Footer from '../../../Footer';
import Answer from '../Answer';
import {
  QuestionsContext,
  QUESTION_MODES,
} from '../../contexts/QuestionsContext';
import questions from '../../questions';

import { Content, StyledContainer } from './styles';

export default function QuestionPage({ questionId }) {
  const questionsContext = useContext(QuestionsContext);
  const question = questions[questionId - 1];
  const arrayAnswer = question.feedbacks.map((fb, index) => ({
    value: question.correct === index.toString() ? 'CORRETA' : 'INCORRETA',
    feedback: fb,
  }));

  const [answer, setAnswer] = useState(
    questionsContext.getAnswer({ questionId: questionId })
  );
  const [openFeedback, setOpenFeedback] = useState(true);

  const headerref = useRef(Header);
  const contrasteValue = useSelector((state) => state.contraste);

  useEffect(() => {
    if (questionsContext.mode === QUESTION_MODES.FEEDBACK) {
      setOpenFeedback(true);
    }
  }, [questionsContext]);

  function onOptionClick(value) {
    console.log(questionsContext.mode)
    if (questionsContext.mode === QUESTION_MODES.DOING) {
      setAnswer(value);
      
      questionsContext.setAnswer({ questionId: questionId, answer: value });
    } else {
      setOpenFeedback(true);
    }
  }

  async function finalizarTentativa() {
    await questionsContext.submit();
    window.location.href = '#/q1';
  }

  return (
    <StyledContainer contraste={contrasteValue}>
      <Header ref={headerref} />
      <Box className='container'>
        <Content contraste={contrasteValue}>
          <Box className='content'>
            <Box className='title'>
              <Typography variant='h5'>Questão {questionId}</Typography>
            </Box>
            <Box className='text'>
              <Typography variant='body1' className='pergunta'>
                {question.description}
              </Typography>
              <div>
                {question.options.map((option, index) => (
                  <Typography
                    key={index.toString()}
                    variant='body1'
                    className={`alternativas ${
                      answer === index.toString() && 'marcada'
                    }`}
                    onClick={() => onOptionClick(index.toString())}
                  >
                    {option}
                  </Typography>
                ))}
              </div>
              {questionsContext.mode === QUESTION_MODES.DOING &&
                questionId === questions.length && (
                  <button disabled={!answer} onClick={finalizarTentativa}>
                    <Typography variant='body1' className=''>
                      Enviar Respostas
                    </Typography>
                  </button>
                )}

              {questionsContext.mode === QUESTION_MODES.FEEDBACK &&
                questionId === questions.length && (
                  <button
                    disabled={!answer}
                    onClick={() => (window.location.href = '#/feedback')}
                  >
                    <Typography variant='body1' className=''>
                      Nota
                    </Typography>
                  </button>
                )}
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer
        next={questionId < questions.length && answer && `/q${questionId + 1}`}
        prev={questionId > 1 ? `/q${questionId - 1}` : undefined}
      />
      {questionsContext.mode === QUESTION_MODES.FEEDBACK && answer && (
        <Answer
          open={openFeedback}
          setOpen={setOpenFeedback}
          content={arrayAnswer}
          answerValue={answer.toString()}
        />
      )}
    </StyledContainer>
  );
}
