import styled, { css } from 'styled-components';
import { createMuiTheme } from '@material-ui/core'
import { Link } from 'react-router-dom';
import { FocusAcessibility } from '../../theme/commonstyles';
import { tooltipsRoundButtons } from '../../theme/commonstyles';

const { breakpoints } = createMuiTheme();

const buttonstyles = css`
  ${FocusAcessibility}

  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;

  width: 45px;
  height: 45px;

  background-color: ${(props) =>
    props.color ? props.color : props.theme.palette.black.buttons};
  border-radius: 50%;
  border: ${(props) => (props.contraste ? 'solid 2px white' : 'none')};
  ${breakpoints.down(600)} {
    margin-left: ${(props) => (props.margin ? '6px' : '0')} !important;
  }
  margin-left: ${(props) => (props.margin ? '8px' : '0')};

  box-shadow: 2px 2px 5px 0px rgba(0, 0, 0, 0.3), 0 1px 2px rgba(0, 0, 0, 0.24);
  transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
  cursor: pointer;

  @media (min-width: 900px) {
    width: 3.5rem;
    height: 3.5rem;
  }
  @media (max-height: 490px){
    width: 2rem;
    height: 2rem;
    position: relative;
    top: -17px;
  }
  svg {
    width: 100%;
    transition: 0.2s ease;
  }

  &:hover {
    background-color: ${(props) =>
    props.color ? props.color : props.theme.palette.black.buttonsHover};
    color: ${(props) => props.theme.palette.white.white};
    box-shadow: 14px 14px 28px rgba(0, 0, 0, 0.25),
      0 8px 8px rgba(0, 0, 0, 0.22);

    svg {
      transform: scale(1.05);
    }
  }

  &:focus {
    outline: none;
  }

  @media (max-height: 800px) and (min-width: 900px) {
    width: 2rem;
    height: 2rem;
    position: relative;
    top: -17px;
  }
  @media (max-width: 300px){
    width: 2.5rem;
    height: 2.5rem;
  }

  ${tooltipsRoundButtons}

  ${(props) =>
    props.disabled
      ? `
    opacity: 0;
    pointer-events: none;
    `
      : 'opacity: 1'};
`;

export const Button = styled(Link)`
  ${buttonstyles};
`;

export const ActionButton = styled.button`
  ${buttonstyles};
  background-color: ${(props) =>
    props.color ? props.color : props.theme.palette.black.buttons};
  ${(props) =>
    props.opacity
      ? `
    opacity: 0;
    pointer-events: none;    
    padding: 0;    
  `
      : ''};
`;
