import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "../../components/Reference";
import { Content } from "./styles";

import imagem from "../../assets/images/info_media/p2/imagem.png";

export default function () {
    const [refNumber, setRefNumber] = useState(0);
    const [openDrawer, setOpenDrawer] = useState(false);

    const handleOpenDrawer = (value) => {
        setRefNumber(value);
        setOpenDrawer(!openDrawer);
    };

    return (
        <DefaultPage
            title="Manejo das crises epilépticas e epilepsia na Atenção Primária à Saúde"
            prev="/p1"
            next="/p3"
            refNumber={refNumber}
            openDrawer={openDrawer}
        >
            <Content>
                <Box className="texto-imagem">
                    <Box className="texto">
                        <Typography variant="body1">
                            <p>
                                O atendimento de pessoas com diagnóstico de epilepsia
                                é comum na Atenção Primária à Saúde. A prevalência
                                mundial estimada de epilepsia ativa é de 0,5% a 1,0%
                                da população, variando conforme idade, gênero e
                                fatores sociais e étnicos. No Brasil, sua prevalência
                                é estimada em 1,8%
                                <Reference
                                    num="1,"
                                    onClick={() => handleOpenDrawer(1)}
                                />
                                <Reference
                                    num="2"
                                    onClick={() => handleOpenDrawer(2)}
                                />
                                .
                            </p>
                            <p>
                                Em um estudo realizado no sul do Brasil, a epilepsia
                                foi mais frequente em classes sociais menos
                                favorecidas e em idosos. Neste mesmo estudo, mais de
                                1/3 dos entrevistados realizavam tratamento
                                inadequado
                                <Reference
                                    num="1,"
                                    onClick={() => handleOpenDrawer(1)}
                                />
                                <Reference
                                    num="3"
                                    onClick={() => handleOpenDrawer(3)}
                                />
                                .
                            </p>
                        </Typography>
                    </Box>
                    <Box className="imagem">
                        <img src={imagem} alt="imagem" />
                    </Box>
                </Box>
                <Box className="left-right">
                    <Box className="left">
                        <Typography variant="body1">
                            <p>
                            É importante diferenciar epilepsia (distúrbio permanente da função ou 
                            estrutura cerebral) de crise epiléptica (manifestação intermitente e 
                            isolada, que pode ter outras causas além da epilepsia), ou seja, nem 
                            todo episódio de “abalos musculares” ou de perda de consciência é uma 
                            crise epiléptica e nem todo episódio de crise epiléptica é por um 
                            diagnóstico de epilepsia
                                <Reference
                                    num="4"
                                    onClick={() => handleOpenDrawer(4)}
                                />
                                .
                            </p>
                        </Typography>
                    </Box>
                    <Box className="divider">

                    </Box>
                    <Box className="right">
                        <Typography variant="body1">
                            <p>
                                Revisaremos conceitos importantes relacionados a
                                definição e classificação das crises epilépticas e
                                epilepsia, suas causas, como é feito o diagnóstico e
                                tratamento (na fase aguda e crônica), além do
                                acompanhamento realizado na APS para pessoas com
                                diagnóstico de Epilepsia. Vamos seguir adiante!
                            </p>
                        </Typography>
                    </Box>
                </Box>
            </Content>
        </DefaultPage>
    );
}
