import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "../../components/Reference";
import { Content } from "./styles";

export default function () {
  const [refNumber, setRefNumber] = useState(0);
  const [openDrawer, setOpenDrawer] = useState(false);

  const handleOpenDrawer = (value) => {
    setRefNumber(value);
    setOpenDrawer(!openDrawer);
  };

  return (
    <DefaultPage
      title="Definição e Classificação das Crises Epilépticas"
      prev="/p2"
      next="/p4"
      refNumber={refNumber}
      openDrawer={openDrawer}
    >
      <Content>
        <Typography variant="body1">
          <strong>
            Veja a seguir a diferença entre Epilepsia e Crise Epilética.
          </strong>
        </Typography>
        <Box className="cards">
          <Box className="card1">
            <Typography variant="body1">
              <p id="title1">
                <b>Epilepsia</b>
              </p>
              <p id="text1">
                Doença crônica que se manifesta por distúrbios epilépticos
                recorrentes, com várias apresentações, entre elas as convulsões 
                (acometimento motor generalizado). A doença é definida por uma
                das seguintes condições
                <Reference num="5" onClick={() => handleOpenDrawer(5)} />:
                <ul>
                  <li>
                    {" "}
                    Duas ou mais crises não provocadas (ou reflexas), ocorrendo
                    com intervalo maior que 24 horas; ou
                  </li>
                  <li>
                    {" "}
                    Uma crise não provocada (ou reflexa) com probabilidade de
                    novas crises ocorrerem nos próximos 10 anos, similar ao risco
                    de recorrência geral (pelo menos 60%) e após duas crises não
                    provocadas; ou
                  </li>
                  <li> Diagnóstico de síndrome epiléptica.</li>
                </ul>
              </p>
            </Typography>
          </Box>
          <Box className="card2">
            <Typography variant="body1">
              <p id="title2">
                <b>Crise Epiléptica</b>
              </p>
              <p id="text2">
                Presença de sinais e/ou sintomas transitórios devido a um evento
                paroxístico da atividade elétrica cerebral, causado por
                descargas anormais, excessivas e síncronas dos neurônios. As
                manifestações da crise epiléptica são diversas, de acordo com a
                área cerebral acometida, podendo ser apresentada por
                <Reference num="5" onClick={() => handleOpenDrawer(5)} />:
                <ul>
                  <li>
                    Abalo motor generalizado (conhecido como convulsão) ou
                    localizado;
                  </li>
                  <li>
                    Manifestações autonômicas ou alteração de consciência;
                  </li>
                  <li>Alterações comportamentais ou sensoriais.</li>
                </ul>
              </p>
            </Typography>
          </Box>
        </Box>
      </Content>
    </DefaultPage>
  );
}
