import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import { Content } from "./styles";

import imagem1 from "../../assets/images/info_media/p7/imagem1.png";
import imagem2 from "../../assets/images/info_media/p7/imagem2.png";

export default function () {
    const [refNumber, setRefNumber] = useState(0);
    const [openDrawer, setOpenDrawer] = useState(false);

    const handleOpenDrawer = (value) => {
        setRefNumber(value);
        setOpenDrawer(!openDrawer);
    };

    const content1 = (
        <>
            <p>
                <b>Condições potencialmente mais graves:</b>
                <ul>
                    <li>Convulsões (febris ou não) com sinais de meningismo;</li>
                    <li>Convulsões e síndromes rapidamente progressivas;</li>
                    <li>
                        Convulsões e síndromes com sinais e sintomas neurológicos;
                    </li>
                    <li>
                        Epilepsia iniciada em idosos (lesões vasculares, neoplásica
                        ou demência);
                    </li>
                    <li>
                        Epilepsia iniciada com crises mioclônicas e astáticas
                        (contrações musculares não rítmicas, como choques,
                        manifestando-se clinicamente como se o corpo se projetasse ao 
                        chão, com queda devido à perda de base para sustentação).
                        Apresentam pior prognóstico.
                    </li>
                </ul>
            </p>
        </>
    );
    const content2 = (
        <>
            <p>
                <b>
                    Indicam barreiras (especialmente psicossociais) para o
                    tratamento:
                </b>
                <ul>
                    <li>Convulsões associadas a sintomas constitucionais;</li>
                    <li>Convulsões associadas a atraso de desenvolvimento;</li>
                    <li>Crises conversivas;</li>
                    <li>Pessoa com risco na condução de veículos;</li>
                    <li>
                        Estigma no convívio com amigos, em especial colegas de
                        escola.
                    </li>
                </ul>
            </p>
        </>
    );

    return (
        <DefaultPage
            title="Definição e Classificação das Crises Epilépticas"
            prev="/p6"
            next="/p8"
            refNumber={refNumber}
            openDrawer={openDrawer}
        >
            <Content>
                <Typography>
                    <p>
                        Algumas situações podem ser consideradas de maior gravidade 
                        (Red Flags) ou com potencial para criar barreiras ao tratamento 
                        (Yellow Flags), devendo ser consideradas na avaliação da pessoa 
                        com crise epiléptica ou epilepsia. Clique nas bandeiras e saiba 
                        mais sobre as situações de maior gravidade relacionadas à epilepsia
                        <Reference num="5" onClick={() => handleOpenDrawer(5)} />:
                    </p>
                </Typography>
                <Box className="dialogs">
                    <Box className="dialog1">
                        <Dialog
                            content={content1}
                            title="Alertas Vermelhos (Red flags)"
                            image={imagem1}
                        />
                    </Box>
                    <Box className="dialog2">
                        <Dialog
                            content={content2}
                            title="Alertas Amarelos (Yellow flags)"
                            image={imagem2}
                        />
                    </Box>
                </Box>
            </Content>
        </DefaultPage>
    );
}
