import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import { Content } from "./styles";

export default function () {
    const [refNumber, setRefNumber] = useState(0);
    const [openDrawer, setOpenDrawer] = useState(false);

    const handleOpenDrawer = (value) => {
        setRefNumber(value);
        setOpenDrawer(!openDrawer);
    };

    const content1 = (
        <>
            <p>
                Relacionada à resposta normal do cérebro a eventos externos, como
                febre, distúrbios hidroeletrolíticos, intoxicação, entre outros.
                Também chamados de fatores desencadeantes.
            </p>
        </>
    );
    const content2 = (
        <>
            <p>
                Síndromes/crises sintomáticas:
                <ul>
                    <li>
                        Sintomáticas agudas: lesões agudas do cérebro como infecção
                        intracraniana, TCE, neoplasia, AVC, efeito de drogas ou
                        distúrbios hidroeletrolíticos locais;
                    </li>
                    <li>
                        Sintomáticas remotas: relacionadas a lesões residuais de
                        processos hipóxico-isquêmicos, infecções ou TCE prévios.
                    </li>
                </ul>
            </p>
            <p>
                Síndromes/crises idiopáticas: não há um fator desencadeante, sendo
                incluídas epilepsias com herança familiar, de caráter genético. Esses
                casos são reservados para síndromes epilépticas com características
                clínicas e eletroencefalográficas específicas.
            </p>
            <p>
                Síndromes/crises criptogênicas: não há um padrão genético
                identificável.
            </p>
        </>
    );

    return (
        <DefaultPage
            title="Causas das Crises Epilépticas"
            prev="/p7"
            next="/p9"
            refNumber={refNumber}
            openDrawer={openDrawer}
        >
            <Content>
                <Typography>
                    <p>
                        As crises epilépticas podem ser desencadeadas por causas
                        externas potencialmente reversíveis (como febre, distúrbios
                        hidroeletrolíticos, intoxicações, entre outros) ou podem ser
                        consequentes a processos internos ao sistema nervoso central
                        (como Trauma Cranioencefálico  (TCE), Acidente Vascular
                        Cerebral (AVC), epilepsia de origem genética, entre outros)
                        <Reference num="5" onClick={() => handleOpenDrawer(5)} />.
                    </p>
                    <p>
                        Para auxiliar nessa diferenciação, deve-se buscar identificar
                        focos infecciosos, presença de febre, bem como comorbidades
                        crônicas que cursam com distúrbios hidroeletrolíticos (como
                        diabetes e doença renal crônica). Além disso, deve-se abordar
                        a história de abuso de álcool ou outras drogas (como cocaína
                        e anfetamina), história de trauma cranioencefálico e
                        medicamentos em uso
                        <Reference num="2," onClick={() => handleOpenDrawer(2)} />
                        <Reference num="5" onClick={() => handleOpenDrawer(5)} />.
                    </p>
                    <p>
                        <b>Clique</b> nos botões abaixo para conhecer a classificação
                        etiológica das síndromes epilépticas
                        <Reference num="4" onClick={() => handleOpenDrawer(4)} />.
                    </p>
                </Typography>
                <Box className=" mt-4 dialogs">
                    <button id="button1">
                        <Dialog
                            buttonText="Síndromes/Crises provocadas (reativas)"
                            title="Síndromes/Crises provocadas (reativas)"
                            content={content1}
                        />
                    </button>
                    <button id="button2">
                        <Dialog
                            buttonText="Síndromes não provocadas"
                            title="Síndromes não provocadas"
                            content={content2}
                        />
                    </button>
                </Box>
            </Content>
        </DefaultPage>
    );
}
