import React, { useEffect, useRef } from "react";
import { StyledContainerCapa, Iniciar } from "./stylesCapa";
import { ContentPage, StyledContainerPage } from "./stylesPage";
import { useSelector } from "react-redux";
import { Typography, Box } from "@material-ui/core";
import Header from "../../components/Header";
import Footer from "../../components/Footer";
import { IniciarCapa } from "../../components/RoundButton/icons";
import disque from "../../assets/images/info_media/Disque_saude.png";

function DefaultPage(props) {
  const contrasteValue = useSelector((state) => state.contraste);

  // para ativar a acessibilidade deixe o acess true
  //nao esqueca de ativar o vlibras alterando o disabled para enabled em public index ;)
  const acess = false;

  const {
    capa,
    wallpaper,
    prev,
    next,
    replay,
    colorFooter,
    children,
    title,
    subtitle,
    refNumber,
    openDrawer,
    conteudoInterno,
    titleCenter,
  } = props;

  function iniciar(event) {
    if (event.key === "Enter" && capa) {
      window.location.href = `#/p1`;
    }
    window.removeEventListener("keydown", iniciar);
  }
  window.addEventListener("keydown", iniciar);

  const headerref = useRef(Header);
  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }
    headerref.current.openRef(key);
  };

  useEffect(() => {
    if (refNumber !== 0 && refNumber !== undefined) {
      openRef(refNumber);
    }
  }, [openDrawer]);

  return capa ? (
    <StyledContainerCapa contraste={contrasteValue} wallpaper={wallpaper}>
      <Header acess={acess} nohome ref={headerref} />
      <Box id='container'>
      <div className='disque'>
          <img alt='disque' src={disque} />
        </div>
        <Box className='content'>
          <Box id='texts'>
            <Box className='wrapper'>
              <Box id='title'>
                <Typography variant='h3'>{title}</Typography>
                <br />
                <Typography variant='body1'>{subtitle}</Typography>
              </Box>
              <Box id='button'>
                <Iniciar to='/p1' contraste={contrasteValue}>
                  <IniciarCapa />
                </Iniciar>
              </Box>
            </Box>
          </Box>
        </Box>
      </Box>
      <Footer color='transparent' logos />
    </StyledContainerCapa>
  ) : (
    <StyledContainerPage
      conteudoInterno={conteudoInterno}
      contraste={contrasteValue}
    >
      <Header acess={acess} ref={headerref} />
      <Box className='container'>
        <ContentPage contraste={contrasteValue}>
          <Box className='contentPage'>
            <Box className={`title ${titleCenter && "titleCenter"}`}>
              <Typography variant='h5'>{title}</Typography>
            </Box>
            {children}
          </Box>
        </ContentPage>
        {conteudoInterno && (
          <Footer prev={prev} next={next} replay={replay} color={colorFooter} />
        )}
      </Box>
      {!conteudoInterno && (
        <Footer prev={prev} next={next} replay={replay} color={colorFooter} />
      )}
    </StyledContainerPage>
  );
}

export default DefaultPage;
